Index: Source/core/dom/Element.h |
diff --git a/Source/core/dom/Element.h b/Source/core/dom/Element.h |
index abc6d8d9c626125fa10618a765abe6e5cf7b55b4..054d6cbab77fb768de0d650f5114e308c0e75fbc 100644 |
--- a/Source/core/dom/Element.h |
+++ b/Source/core/dom/Element.h |
@@ -175,8 +175,8 @@ public: |
int offsetHeight(); |
// FIXME: Replace uses of offsetParent in the platform with calls |
- // to the render layer and merge bindingsOffsetParent and offsetParent. |
- Element* bindingsOffsetParent(); |
+ // to the render layer and merge offsetParentForBindings and offsetParent. |
+ Element* offsetParentForBindings(); |
Element* offsetParent(); |
int clientLeft(); |